@@ -1,4 +1,6 @@
 """Ansible runtime environment manager."""
+from __future__ import annotations
+
 import contextlib
 import importlib
 import json
@@ -12,7 +14,7 @@ import warnings
 from collections import OrderedDict
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Optional, Union, no_type_check
+from typing import TYPE_CHECKING, Any, Callable, no_type_check
 
 import subprocess_tee
 from packaging.version import Version
@@ -24,6 +26,7 @@ from ansible_compat.config import (
     parse_ansible_version,
 )
 from ansible_compat.constants import (
+    META_MAIN,
     MSG_INVALID_FQRL,
     RC_ANSIBLE_OPTIONS_ERROR,
     REQUIREMENT_LOCATIONS,
@@ -47,6 +50,7 @@ else:
 _logger = logging.getLogger(__name__)
 # regex to extract the first version from a collection range specifier
 version_re = re.compile(":[>=<]*([^,]*)")
+namespace_re = re.compile("^[a-z][a-z0-9_]+$")
 
 
 class AnsibleWarning(Warning):
@@ -78,7 +82,7 @@ class CollectionVersion(Version):
 class Plugins:  # pylint: disable=too-many-instance-attributes
     """Dataclass to access installed Ansible plugins, uses ansible-doc to retrieve them."""
 
-    runtime: "Runtime"
+    runtime: Runtime
     become: dict[str, str] = field(init=False)
     cache: dict[str, str] = field(init=False)
     callback: dict[str, str] = field(init=False)
@@ -143,9 +147,9 @@ class Plugins:  # pylint: disable=too-many-instance-attributes
 class Runtime:
     """Ansible Runtime manager."""
 
-    _version: Optional[Version] = None
+    _version: Version | None = None
     collections: OrderedDict[str, Collection] = OrderedDict()
-    cache_dir: Optional[Path] = None
+    cache_dir: Path | None = None
     # Used to track if we have already initialized the Ansible runtime as attempts
     # to do it multiple tilmes will cause runtime warnings from within ansible-core
     initialized: bool = False
@@ -153,13 +157,13 @@ class Runtime:
 
     def __init__(
         self,
-        project_dir: Optional[Path] = None,
+        project_dir: Path | None = None,
         *,
         isolated: bool = False,
-        min_required_version: Optional[str] = None,
+        min_required_version: str | None = None,
         require_module: bool = False,
         max_retries: int = 0,
-        environ: Optional[dict[str, str]] = None,
+        environ: dict[str, str] | None = None,
     ) -> None:
         """Initialize Ansible runtime environment.
 
@@ -311,12 +315,12 @@ class Runtime:
 
     def run(  # ruff: disable=PLR0913
         self,
-        args: Union[str, list[str]],
+        args: str | list[str],
         *,
         retry: bool = False,
         tee: bool = False,
-        env: Optional[dict[str, str]] = None,
-        cwd: Optional[Path] = None,
+        env: dict[str, str] | None = None,
+        cwd: Path | None = None,
     ) -> CompletedProcess:
         """Execute a command inside an Ansible environment.
 
@@ -332,6 +336,9 @@ class Runtime:
         # from parsing its JSON output due to extra debug messages on stdout.
         env["ANSIBLE_DEBUG"] = "0"
 
+        # https://github.com/ansible/ansible-lint/issues/3522
+        env["ANSIBLE_VERBOSE_TO_STDERR"] = "True"
+
         for _ in range(self.max_retries + 1 if retry else 1):
             result = run_func(
                 args,
@@ -374,8 +381,8 @@ class Runtime:
 
     def version_in_range(
         self,
-        lower: Optional[str] = None,
-        upper: Optional[str] = None,
+        lower: str | None = None,
+        upper: str | None = None,
     ) -> bool:
         """Check if Ansible version is inside a required range.
 
@@ -389,9 +396,9 @@ class Runtime:
 
     def install_collection(
         self,
-        collection: Union[str, Path],
+        collection: str | Path,
         *,
-        destination: Optional[Path] = None,
+        destination: Path | None = None,
         force: bool = False,
     ) -> None:
         """Install an Ansible collection.
@@ -436,7 +443,7 @@ class Runtime:
     def install_collection_from_disk(
         self,
         path: Path,
-        destination: Optional[Path] = None,
+        destination: Path | None = None,
     ) -> None:
         """Build and install collection from a given disk path."""
         if not self.version_in_range(upper="2.11"):
@@ -549,7 +556,7 @@ class Runtime:
 
     def prepare_environment(  # noqa: C901
         self,
-        required_collections: Optional[dict[str, str]] = None,
+        required_collections: dict[str, str] | None = None,
         *,
         retry: bool = False,
         install_local: bool = False,
@@ -557,7 +564,7 @@ class Runtime:
         role_name_check: int = 0,
     ) -> None:
         """Make dependencies available if needed."""
-        destination: Optional[Path] = None
+        destination: Path | None = None
         if required_collections is None:
             required_collections = {}
 
@@ -568,20 +575,27 @@ class Runtime:
         for req_file in REQUIREMENT_LOCATIONS:
             self.install_requirements(Path(req_file), retry=retry, offline=offline)
 
-        galaxy_path = Path("galaxy.yml")
-        if galaxy_path.exists():
-            data = yaml_from_file(galaxy_path)
-            if isinstance(data, dict) and "dependencies" in data:
-                for name, required_version in data["dependencies"].items():
-                    _logger.info(
-                        "Provisioning collection %s:%s from galaxy.yml",
-                        name,
-                        required_version,
-                    )
-                    self.install_collection(
-                        f"{name}:{required_version}",
-                        destination=destination,
-                    )
+        self._prepare_ansible_paths()
+
+        if not install_local:
+            return
+
+        for gpath in search_galaxy_paths(self.project_dir):
+            # processing all found galaxy.yml files
+            galaxy_path = Path(gpath)
+            if galaxy_path.exists():
+                data = yaml_from_file(galaxy_path)
+                if isinstance(data, dict) and "dependencies" in data:
+                    for name, required_version in data["dependencies"].items():
+                        _logger.info(
+                            "Provisioning collection %s:%s from galaxy.yml",
+                            name,
+                            required_version,
+                        )
+                        self.install_collection(
+                            f"{name}:{required_version}",
+                            destination=destination,
+                        )
 
         if self.cache_dir:
             destination = self.cache_dir / "collections"
@@ -591,11 +605,6 @@ class Runtime:
                 destination=destination,
             )
 
-        self._prepare_ansible_paths()
-
-        if not install_local:
-            return
-
         if Path("galaxy.yml").exists():
             if destination:
                 # while function can return None, that would not break the logic
@@ -615,14 +624,20 @@ class Runtime:
                     colpath.unlink()
 
             # molecule scenario within a collection
-            self.install_collection_from_disk(Path("."), destination=destination)
+            self.install_collection_from_disk(
+                galaxy_path.parent,
+                destination=destination,
+            )
         elif (
             Path().resolve().parent.name == "roles"
             and Path("../../galaxy.yml").exists()
         ):
             # molecule scenario located within roles/<role-name>/molecule inside
             # a collection
-            self.install_collection_from_disk(Path("../.."), destination=destination)
+            self.install_collection_from_disk(
+                Path("../.."),
+                destination=destination,
+            )
         else:
             # no collection, try to recognize and install a standalone role
             self._install_galaxy_role(
@@ -636,7 +651,7 @@ class Runtime:
     def require_collection(
         self,
         name: str,
-        version: Optional[str] = None,
+        version: str | None = None,
         *,
         install: bool = True,
     ) -> None:
@@ -776,13 +791,17 @@ class Runtime:
         """
         yaml = None
         galaxy_info = {}
-        meta_filename = Path(project_dir) / "meta" / "main.yml"
 
-        if not meta_filename.exists():
+        for meta_main in META_MAIN:
+            meta_filename = Path(project_dir) / meta_main
+
+            if meta_filename.exists():
+                break
+        else:
             if ignore_errors:
                 return
-        else:
-            yaml = yaml_from_file(meta_filename)
+
+        yaml = yaml_from_file(meta_filename)
 
         if yaml and "galaxy_info" in yaml:
             galaxy_info = yaml["galaxy_info"]
@@ -874,3 +893,17 @@ def _get_galaxy_role_ns(galaxy_infos: dict[str, Any]) -> str:
 def _get_galaxy_role_name(galaxy_infos: dict[str, Any]) -> str:
     """Compute role name from meta/main.yml."""
     return galaxy_infos.get("role_name", "")
+
+
+def search_galaxy_paths(search_dir: Path) -> list[str]:
+    """Search for galaxy paths (only one level deep)."""
+    galaxy_paths: list[str] = []
+    for file in [".", *os.listdir(search_dir)]:
+        # We ignore any folders that are not valid namespaces, just like
+        # ansible galaxy does at this moment.
+        if file != "." and not namespace_re.match(file):
+            continue
+        file_path = search_dir / file / "galaxy.yml"
+        if file_path.is_file():
+            galaxy_paths.append(str(file_path))
+    return galaxy_paths
